@@ -1,6 +1,9 @@
 use utf8;
 package Etcd3::Auth;
 
+use strict;
+use warnings;
+
 =encoding utf8
 
 =head1 NAME
@@ -9,7 +12,7 @@ Etcd3::Auth
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 DESCRIPTION
 
