@@ -19,7 +19,7 @@ Etcd3:::Auth::UserRevokeRole
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 DESCRIPTION
 
@@ -27,6 +27,8 @@ revokes a role of specified user.
 
 =head2 endpoint
 
+/auth/user/revoke
+
 =cut
 
 has endpoint => (
@@ -37,7 +39,7 @@ has endpoint => (
 
 =head2 name
 
-name of role
+name of user
 
 =cut
 
